<?php

namespace Hrm\Jobunit\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Hrm\Jobunit\Http\Requests\JobunitRequest;
use Hrm\Jobunit\Interfaces\JobunitRepositoryInterface;
use Hrm\Jobunit\Models\Jobunit;

/**
 * Resource controller class for jobunit.
 */
class JobunitResourceController extends BaseController
{

    /**
     * Initialize jobunit resource controller.
     *
     * @param type JobunitRepositoryInterface $jobunit
     *
     * @return null
     */
    public function __construct(JobunitRepositoryInterface $jobunit)
    {
        parent::__construct();
        $this->repository = $jobunit;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Hrm\Jobunit\Repositories\Criteria\JobunitResourceCriteria::class);
    }

    /**
     * Display a list of jobunit.
     *
     * @return Response
     */
    public function index(JobunitRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Hrm\Jobunit\Repositories\Presenter\JobunitPresenter::class)
                ->$function();
        }

        $jobunits = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('jobunit::jobunit.names'))
            ->view('jobunit::jobunit.index', true)
            ->data(compact('jobunits', 'view'))
            ->output();
    }

    /**
     * Display jobunit.
     *
     * @param Request $request
     * @param Model   $jobunit
     *
     * @return Response
     */
    public function show(JobunitRequest $request, Jobunit $jobunit)
    {

        if ($jobunit->exists) {
            $view = 'jobunit::jobunit.show';
        } else {
            $view = 'jobunit::jobunit.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('jobunit::jobunit.name'))
            ->data(compact('jobunit'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new jobunit.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(JobunitRequest $request)
    {

        $jobunit = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('jobunit::jobunit.name')) 
            ->view('jobunit::jobunit.create', true) 
            ->data(compact('jobunit'))
            ->output();
    }

    /**
     * Create new jobunit.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(JobunitRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $jobunit                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('jobunit::jobunit.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('jobunit/jobunit/' . $jobunit->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/jobunit/jobunit'))
                ->redirect();
        }

    }

    /**
     * Show jobunit for editing.
     *
     * @param Request $request
     * @param Model   $jobunit
     *
     * @return Response
     */
    public function edit(JobunitRequest $request, Jobunit $jobunit)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('jobunit::jobunit.name'))
            ->view('jobunit::jobunit.edit', true)
            ->data(compact('jobunit'))
            ->output();
    }

    /**
     * Update the jobunit.
     *
     * @param Request $request
     * @param Model   $jobunit
     *
     * @return Response
     */
    public function update(JobunitRequest $request, Jobunit $jobunit)
    {
        try {
            $attributes = $request->all();

            $jobunit->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('jobunit::jobunit.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('jobunit/jobunit/' . $jobunit->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('jobunit/jobunit/' . $jobunit->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the jobunit.
     *
     * @param Model   $jobunit
     *
     * @return Response
     */
    public function destroy(JobunitRequest $request, Jobunit $jobunit)
    {
        try {

            $jobunit->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('jobunit::jobunit.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('jobunit/jobunit/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('jobunit/jobunit/' . $jobunit->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple jobunit.
     *
     * @param Model   $jobunit
     *
     * @return Response
     */
    public function delete(JobunitRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('jobunit::jobunit.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('jobunit/jobunit'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/jobunit/jobunit'))
                ->redirect();
        }

    }

    /**
     * Restore deleted jobunits.
     *
     * @param Model   $jobunit
     *
     * @return Response
     */
    public function restore(JobunitRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('jobunit::jobunit.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/jobunit/jobunit'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/jobunit/jobunit/'))
                ->redirect();
        }

    }

}
